@@ -16,33 +16,42 @@ use MojoX::Log::Log4perl;
 use Log::Log4perl qw/:easy/;
 use File::Temp;
 use JSON::MaybeXS qw( encode_json decode_json );
+use Carp qw( carp );
+use Mojo::Util qw( monkey_patch );
 
 # ABSTRACT: Construct command line and perl clients for RESTful services.
-our $VERSION = '1.12'; # VERSION
+our $VERSION = '1.14'; # VERSION
 
 
 has server_url => '';
-has [qw(tx res userinfo client)];
+has [qw(tx res userinfo ua )];
 has _remote => ''; # Access via remote()
 has _cache => sub { + {} }; # cache of credentials
 
+sub client
+{
+  carp "Clustericious::Client->client is deprecated (use ua instead)";
+  shift->ua(@_);
+}
+
 sub import
 {
-    my $class = shift;
-    my $caller = caller;
+  my($class) = @_;
+  my $caller = caller;
 
-    {
+  monkey_patch $caller, route => \&route;
+  monkey_patch $caller, route_meta => \&route_meta;
+  monkey_patch $caller, route_args => \&route_args;
+  monkey_patch $caller, route_doc => sub {
+    Clustericious::Client::Meta->add_route( $caller, @_ );
+  };
+  monkey_patch $caller, object => \&object;
+  monkey_patch $caller, import => sub {};
+
+  do {
     no strict 'refs';
     push @{"${caller}::ISA"}, $class unless $caller->isa($class);
-    *{"${caller}::route"} = \&route;
-    *{"${caller}::route_meta"} = \&route_meta;
-    *{"${caller}::route_args"} = \&route_args;
-    *{"${caller}::route_doc"} = sub {
-        Clustericious::Client::Meta->add_route( $caller, @_ )
-    };
-    *{"${caller}::object"} = \&object;
-    *{"${caller}::import"} = sub {};
-    }
+  };
 }
 
 
@@ -56,40 +65,44 @@ sub _mojo_user_agent_factory
 
 sub new
 {
-    my $self = shift->SUPER::new(@_);
-    my %args = @_;
+  my($class, %args) = @_;
 
-    if ($self->{app})
+  my $config = delete $args{config};
+  
+  my $self = $class->SUPER::new(%args);
+
+  $self->{_base_config} = $config if $config;
+
+  if($self->{app})
+  {
+    my $app = $self->{app};
+    $app = $app->new() unless ref($app);
+    my $ua = $self->_mojo_user_agent_factory();
+    return undef unless $ua;
+    eval { $ua->server->app($app) } // $ua->app($app);
+    $self->ua($ua);
+  }
+  else
+  {
+    $self->ua($self->_mojo_user_agent_factory());
+    unless(length $self->server_url)
     {
-        my $app = $self->{app};
-        $app = $app->new() unless ref($app);
-        my $client = $self->_mojo_user_agent_factory();
-        return undef unless $client;
-        eval { $client->server->app($app) } // $client->app($app);
-
-        $self->client($client);
-    }
-    else
-    {
-        $self->client($self->_mojo_user_agent_factory());
-        if (not length $self->server_url)
-        {
-            my $url = $self->_config->url;
-            $url =~ s{/$}{};
-            $self->server_url($url);
-        }
+      my $url = $self->config->url;
+      $url =~ s{/$}{};
+      $self->server_url($url);
     }
+  }
 
-    my $client = $self->client;
-    $client->transactor->name($self->user_agent_string);
-    $client->inactivity_timeout($ENV{CLUSTERICIOUS_KEEP_ALIVE_TIMEOUT} || 300);
+  my $ua = $self->ua;
+  $ua->transactor->name($self->user_agent_string);
+  $ua->inactivity_timeout($ENV{CLUSTERICIOUS_KEEP_ALIVE_TIMEOUT} || 300);
 
-    if(eval { require Clustericious::Client::Local; })
-    {
-        Clustericious::Client::Local->local($self);
-    }
+  if(eval { require Clustericious::Client::Local; })
+  {
+    Clustericious::Client::Local->local($self);
+  }
 
-    return $self;
+  $self;
 }
 
 
@@ -100,7 +113,7 @@ sub remote {
     my $remote = shift;
     unless ($remote) { # reset to default
         $self->{_remote} = '';
-        $self->server_url($self->_config->url);
+        $self->server_url($self->config->url);
         return;
     }
     my $info = $self->_base_config->remotes->$remote;
@@ -124,14 +137,14 @@ sub login {
     my ($user,$pw) =
            @_==2 ? @_
          : @_    ?  @args{qw/username password/}
-         : map $self->_config->$_, qw/username password/;
+         : map $self->config->$_, qw/username password/;
     $self->userinfo(join ':', $user,$pw);
 }
 
 
 sub errorstring {
     my $self = shift;
-    WARN "Missing response in client object" unless $self->res;
+    WARN "Missing response in ua object" unless $self->res;
     return unless $self->res;
     return if $self->res->code && $self->res->is_status_class(200);
     my $error = $self->res->error;
@@ -387,11 +400,11 @@ sub _doit {
         $body = encode_json $body;
     }
 
-    return $self->client->build_tx($method, $url, $headers, $body, $cb) if $cb;
+    return $self->ua->build_tx($method, $url, $headers, $body, $cb) if $cb;
 
-    my $tx = $self->client->build_tx($method, $url, $headers, $body);
+    my $tx = $self->ua->build_tx($method, $url, $headers, $body);
 
-    $tx = $self->client->start($tx);
+    $tx = $self->ua->start($tx);
     my $res = $tx->res;
     $self->res($res);
     $self->tx($tx);
@@ -444,7 +457,7 @@ sub _doit {
         ERROR $res->body if $res->body;
         return undef;
     }
-    my $failover_urls = $self->_config->failover_urls(default => []);
+    my $failover_urls = $self->config->failover_urls(default => []);
     unless (@$failover_urls) {
         ERROR $msg;
         return undef;
@@ -467,7 +480,7 @@ sub _mycallback
     my $cb = shift;
     sub
     {
-        my ($client, $tx) = @_;
+        my ($ua, $tx) = @_;
 
         $self->res($tx->res);
         $self->tx($tx);
@@ -493,48 +506,61 @@ sub _sanitize_url {
     return $url unless $url->userinfo;
     my $c = $url->clone;
     $c->userinfo("user:*****");
-    return $c;
+    $c;
 }
 
-sub _appname {
-    my $self = shift;
-    (my $appname = ref $self) =~ s/:.*$//;
-    return $appname;
+sub _appname
+{
+  my($self) = @_;
+  (my $appname = ref $self) =~ s/:.*$//;
+  $appname;
 }
 
-sub _config {
-    my $self = shift;
-    my $conf = $self->_base_config;
-    if (my $remote = $self->_remote) {
-        return $conf->remotes->$remote;
-    }
-    return $conf;
+
+sub config
+{
+  my($self) = @_;  
+  my $conf = $self->_base_config;
+  if (my $remote = $self->_remote)
+  {
+    return $conf->remotes->$remote;
+  }
+  $conf;
 }
 
-sub _base_config {
-    # Independent of remotes
-    my $self = shift;
-    return $self->{_base_config} if defined($self->{_base_config});
-    
+sub _config
+{
+  carp "Clustericious::Client->_config has been deprecated use config instead";
+  shift->config(@_);
+}
+
+sub _base_config
+{
+  # Independent of remotes
+  my($self) = @_;
+  unless(defined $self->{_base_config})
+  {
     my $config_name = ref $self;
     $config_name =~ s/::Client$//;
     $config_name =~ s/::/-/;
-    
     $self->{_base_config} = Clustericious::Config->new($config_name);
     $self->{_base_config}->{url} //= Clustericious->_default_url($config_name);
-    return $self->{_base_config};
+  }
+  
+  $self->{_base_config};
 }
 
-sub _has_auth {
-    my $self = shift;
-    return 0 unless $self->_config->username(default => '');
-    return 0 unless $self->_config->password(default => '');
-    return 1;
+sub _has_auth
+{
+  my($self) = @_;
+  my $config = $self->config;
+  $config->username(default => '') && password(default => '') ? 1 : 0;
 }
 
-sub _can_auth {
-    my $self = shift;
-    return -t STDIN ? 1 : 0;
+sub _can_auth
+{
+  my $self = shift;
+  -t STDIN ? 1 : 0;
 }
 
 sub _get_user_pw  {
@@ -610,7 +636,7 @@ Clustericious::Client - Construct command line and perl clients for RESTful serv
 
 =head1 VERSION
 
-version 1.12
+version 1.14
 
 =head1 SYNOPSIS
 
@@ -692,10 +718,20 @@ a data structure if it is application/json.
 This class inherits from L<Mojo::Base>, and handles attributes like
 that class.  The following additional attributes are used.
 
+=head2 config
+
+Configuration object.  Defaults to the appropriate L<Clustericious::Config>
+class.
+
+=head2 ua
+
+User agent to process the HTTP stuff with.  Defaults to a
+L<Mojo::UserAgent>.
+
 =head2 client
 
-A client to process the HTTP stuff with.  Defaults to a
-L<Mojo::UserAgent>.
+Deprecated alias for L</ua> above.  Do not use in new code.  May be removed
+in the future.
 
 =head2 app
 
