@@ -9,19 +9,19 @@ use PerlX::Maybe qw( maybe );
 use Path::Class qw( dir );
 
 # ABSTRACT: Handle data types automatically
-our $VERSION = '1.12'; # VERSION
+our $VERSION = '1.14'; # VERSION
 
 
 sub _default_coders
 {
-  my %coders = 
-  map { $_ => 1 }
-  map { $_ =~ s/\.pm$//; $_ } 
-  map { $_->basename }
-  grep { ! $_->is_dir } 
-  map { $_->children( no_hidden => 1 ) } 
-  grep { -d $_ } 
-  map { dir($_, 'Clustericious', 'Coder' )} @INC;
+  my %coders =
+    map { $_ => 1 }
+    map { $_ =~ s/\.pm$//; $_ }
+    map { $_->basename }
+    grep { ! $_->is_dir }
+    map { $_->children( no_hidden => 1 ) }
+    grep { -d $_ }
+    map { dir $_, 'Clustericious', 'Coder' } @INC;
   [ keys %coders ];
 }
 
@@ -62,7 +62,8 @@ sub register
 
     foreach my $type (map { /^([^;]*)/ } # get only stuff before ;
                       split(',', $headers->header('Accept') || ''),
-                      $headers->content_type || '') {
+                      $headers->content_type || '')
+    {
         return $type if $types{$type} and $types{$type}->{encode};
     }
 
@@ -77,12 +78,9 @@ sub register
     my ($r, $c, $output, $data) = @_;
 
     my $type = $find_type->($c);
-    LOGDIE "no encoder for $type" unless $types{$type}{encode};
-    $$output = $types{$type}->{encode}->($c->stash("autodata"), $c);
-
+    LOGDIE "no encoder for $type" unless $types{$type}->{encode};
+    $$output = $types{$type}->{encode}->($c->stash("autodata"));
     $c->tx->res->headers->content_type($type);
-
-    1;
   });
 
   my $parse_autodata = sub {
@@ -95,8 +93,9 @@ sub register
     }
     my $entry = $types{$content_type} || $types{$default_decode};
 
+    # TODO: avoid passing $c in, only used by
+    # application/x-www-form-urlencoded above
     $c->stash->{autodata} = $entry->{decode}->($c->req->body, $c);
-    $c->stash->{autodata};
   };
 
   $app->plugins->on( parse_autodata => $parse_autodata );
@@ -141,7 +140,7 @@ Clustericious::Plugin::AutodataHandler - Handle data types automatically
 
 =head1 VERSION
 
-version 1.12
+version 1.14
 
 =head1 SYNOPSIS
 
