@@ -8,7 +8,7 @@ use base qw( Mojolicious::Plugin );
 use Mojo::ByteStream qw( b );
 
 # ABSTRACT: Helpers for Clustericious
-our $VERSION = '1.12'; # VERSION
+our $VERSION = '1.14'; # VERSION
 
 
 sub register
@@ -37,6 +37,19 @@ sub register
     $c->res->headers->location($where);
     $c->render(text => "moved to $where");
   });
+
+
+  do {
+    my $client_class = ref($app) . "::Client";
+    $client_class = 'Clustericious::Client'
+      unless $client_class->can('new')
+      ||     eval qq{ require $client_class; $client_class->can('new') };
+
+    $app->helper(client => sub {
+      $client_class->new(config => $app->config);
+    });
+  };
+
 }
 
 1;
@@ -53,7 +66,7 @@ Clustericious::Plugin::ClustericiousHelpers - Helpers for Clustericious
 
 =head1 VERSION
 
-version 1.12
+version 1.14
 
 =head1 DESCRIPTION
 
@@ -82,6 +95,12 @@ B<DEPRECATED>
 
 Render a 301 response.
 
+=head2 client
+
+ my $client = $c->client;
+
+Returns the appropriate L<Clustericious::Client> object for your app.
+
 =head1 AUTHOR
 
 Original author: Brian Duggan
